可可西里 (豆瓣)
Description: 可可西里电影简介和剧情介绍,可可西里影评、图片、预告片、影讯、论坛、在线购票
Keywords: 可可西里,可可西里,可可西里影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.202豆瓣电影Top250

# 可可西里 (2004)

导演: 陆川
编剧: 陆川
主演: 多布杰 / 张垒 / 奇道 / 赵雪莹 / 马占林 / 赵一穗
类型: 剧情 / 犯罪
制片国家/地区: 中国大陆 / 中国香港
语言: 汉语普通话 / 藏语
上映日期: 2004-10-01(中国大陆) / 2005-04-21(中国香港)
片长: 85分钟(中国大陆) / 90分钟(美国) / 98分钟(阿根廷)
又名: Kekexili: Mountain Patrol
IMDb: tt0386651
豆瓣评分
引用
8.9
287450人评价
5星
53.1%
4星
38.1%
3星
8.1%
2星
0.5%
1星
0.2%
好于 98% 犯罪片
好于 98% 剧情片
想看 看过
评价:
推荐

## 可可西里的剧情简介 · · · · · ·

尕玉（张磊 饰）本来是个警察，为了调查藏羚羊猎杀状况，他假扮记者身份，随考察团来到可可西里——那里气候寒冷、空气稀薄，含氧量极低。就在这个人类生存的“禁区”，尕玉目睹了一幕幕人性的贪婪以及人类与环境的狂暴冲突。首先是藏羚羊保护站的巡山队员被盗猎人枪杀，接下来他们见到了悲惨的一幕：盗猎者逃走，只留下众多只剩嶙峋白骨的藏羚羊。巡山队员在恶劣的环境中追捕凶手，最终只夺回了一部份的藏羚羊皮毛。一方面要与恶劣的自然环境抗争、另一方面还要与凶残的盗猎者周旋，巡山队员和尕玉面临着生死考验。 ©豆瓣

## 可可西里的演职员 · · · · · · ( 全部 18 )

- 陆川 导演
- 多布杰 饰 日泰
- 张垒 饰 尕玉
- 奇道 饰 刘栋
- 赵雪莹 饰 冷雪
- 马占林 饰 马占林

## 可可西里的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片235 · 添加 )

## 可可西里的获奖情况 · · · · · · ( 全部 )

- 第41届台北金马影展
- 金马奖 最佳剧情片

- 第25届香港电影金像奖
- 最佳亚洲电影
- 陆川

- 第17届东京国际电影节
- 主竞赛单元 最佳影片(提名)
- 陆川

## 喜欢这部电影的人也喜欢 · · · · · ·

  猫鼠游戏

  杀人回忆

  七宗罪

  血钻

  熔炉

  香水

  上帝之城

  恐怖直播

  无人区

  教父3

我要写短评

## 可可西里的短评 · · · · · · ( 全部 53123 条 )

热门 / 最新 / 好友

### 3232 有用 罗弘霉素 看过 2010-03-02 05:46:44

分不是给你陆川的，是给那些人

### 2008 有用 峰峰峰峰 看过 2014-04-12 18:11:03

见过磕长头的人吗？他们的手和脸脏得很，可他们的心特别干净。我卖过皮子，可我没办法。

### 910 有用 战国客 看过 2008-03-18 14:05:25

只能说陆川选对了题材~~

### 3155 有用 love mime 看过 2009-01-23 00:18:58

“你看过磕长头的人吗？他们的脸和手特别脏，但他们的心特别干净。”

### 1937 有用 三丁 看过 2010-04-13 12:25:24

看了陆川近年的作品...觉得这片绝壁不是他拍的

> 更多短评 53123条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 可可西里的影评 · · · · · · ( 全部 919 条 )

热门 / 最新 / 好友
Echo 2005-10-26 15:09:08

## 向死而生：用生命诠释的存在、道德和信仰

在这里，你留下的每个脚印都有可能是人类留下的第一个脚印。 ——题记 镜头一：一只老鹰飞临，紧接着一群老鹰，然后是强巴干净赤裸的背，天葬师挥刀…… 镜头二：马占林久久地站在日泰静默的尸体旁边，不远处是正在离开的他的同伴，在远处是静默的山峦…… 镜头三：天，静静无... (展开)
2317 104 221回应 收起
年华的蔻 2006-12-08 19:12:16

## 现实与电影

这篇影评可能有剧透

刚看完《可可西里》，心里很不是滋味。这部根据真人真事改编的电影用真实的镜头讲述了一个生与死的故事。 日泰队长无疑是一个英雄人物，虽然他也卖藏羚羊皮，但那只是一种使巡山队生存下去的方法——“用死去的羊保护活着的羊”。 电影中的三个人物是我感触很多，... (展开)
627 39 64回应 收起
呂永佳 2005-07-20 16:32:25

## 可可西里：旁觀他人的痛苦

若你不被這些照片刺痛，不對這些照片畏懼，若你不因而設法中止造成這些殺戮災劫的遠因近由──凡是欠缺這類反應的人，吳爾芙視之為無道德良心的禽獸。而她認為，我們並非禽獸，我們這些有教養的一群。我們的不足之處是想像力或情感上的無法投入，我們無法在心智上掌握這現實。... (展开)
237 34 39回应 收起
薾苨 2013-06-08 22:58:59

## 杰桑·索南达杰（不是影评）

据资料道现存藏羚羊数量约为7万至10万只，比起半个世纪以前有百万只的情况相当危急，如果盗猎情况未有改善估计20年内藏羚羊将绝种。 为保护藏羚羊，青海省治多县委副书记杰桑‧索南达杰组建了中国第一支武装反偷猎队伍——西部工委。但在1994年1月18日，在押送二十名被捕的... (展开)
114 9回应 收起
谷球球 2009-02-14 08:40:35

## fuerte

四个月前我来到这座西班牙小城读书。 四天前得知市立图书馆在办免费影展，2月13日，《可可西里》。 我想到了自己少得可怜、又被拖欠了近半个月的奖学金。想起这四个月来我窘迫的生活，我一次电影院都没有进过。 于是我决定去看看这部一直想看却一直错过的《可可西里》。 放映... (展开)
152 15 8回应 收起
小龙 2008-01-31 15:44:33

## 谁的《可可西里》

仅从题材上来说，《可可西里》的命题无疑是悲壮与形而上的，它包含了生命、信仰、生存境况、人文关怀以及环境和谐诸多当代语境下时髦的哲学词组。在这一点上，导演陆川再次表现出了在他头一部电影《寻枪》里就表现出来的乖巧以及对主题遴选的敏感。导演陆川显然是一个聪明人，... (展开)
397 355 193回应 收起
黄色动力伞 2009-05-17 15:01:27

## 《寻枪》之后，《南京》之前

如果说《寻枪》里的陆川还是一个仰仗姜文的力量才得以实现电影抱负并时时受到掣肘的新晋导演，那么在《可可西里》中，作为编剧兼导演的他已经完全获得了对电影创作的控制权，并使之印上了强烈的个人色彩。 李泽厚评价《可可西里》“是中国电影美学的革命”，美国“元哲学”名... (展开)
83 6 15回应 收起
思阳 2009-07-20 03:49:23

## 居然真的遇见过要买藏羚羊毛的人

从芝加哥返华盛顿的飞机上，一个金融界的白领还问我能否在西藏找到世界上最珍贵的羊毛。他的梦想就是能拥有一件这种毛制成的名贵衣服。他把这种皮毛的优质与显赫对我述说了几乎半个小说，他的眼里闪闪发光。他说可惜这种羊毛交易是非法的。他问我能否出钱让西藏人帮他找羊毛。... (展开)
68 12 17回应 收起
jfflnzw 2017-06-02 16:40:37

## 是谁的救赎？

可可西里有什么？有藏羚羊，有草原，有雪山，有风暴，有混乱的吉普车匆忙碾过，有一群固执而不知所谓的男人，当然，最重要的，还有死亡。 藏羚羊死在疯狂的扫射中，雪山和草原死在时间的静静关注中，吉普车死在一团暴烈的火焰中，而男人们，死在自己的信念中。最后，活着的人回... (展开)
54 4 0回应 收起
不要不开心哦 2017-05-17 15:12:28

## 生命与信仰的礼赞

这篇影评可能有剧透

生命到底是怎样的？灯光黯淡，人来人往，模糊了太多关于生命脆弱的思考。人类用白衣与铿锵作响的医疗器械为生命筑起坚强的防盗门，大段大段的话剧的华丽台词粉饰了生命的本质，让世人以为生命坚强到无坚不摧。于是，那么多无知者轻易放弃，为死奔命的他们前仆后继，一个又一个... (展开)
52 6 5回应 收起

> 更多影评 919篇

添加新讨论

## 讨论区 · · · · · ·

求个未删减的资源 好人一生平安 祝你发财！ | 来自杜大官人 | 8 回应 | 2022-11-24 16:42:11
关于流沙 | 来自南派三叔 | 5 回应 | 2022-11-06 03:31:39
疑问：保护特殊动物是谁的道德标准 | 来自shabbyDD | 10 回应 | 2022-11-06 03:29:40
都是穷人，都是为了生存，为什么他们那么穷？为什... | 来自bitgod | 8 回应 | 2022-11-05 01:02:52
看多少分钟的版本 | 来自先是云 |  | 2022-10-30 16:24:50

> 去这部影片的讨论区（全部136条）

## 关于《可可西里》的问题 · · · · · · ( 全部10个 )

- 刘栋被活埋怎么解释？ 4人回答
- 那个20岁的马锐（被打中了大腿动脉）到底是不是被误杀的啊？ 3人回答

> 全部10个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 免费观看
- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 芒果TV 免费观看
- 西瓜视频 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【城市印象】— 跟着电影去旅行 (狷介有乌青)
- 【豆瓣五星电影集中营】(2/3) (影志)
- 今敏《造梦机器》剧组100部电影推荐 (恶魔的步调)

## 谁在看这部电影 · · · · · ·

- 豆友O4WfE_FJiI
  5分钟前 看过
- ヒグレ
  6分钟前 想看
- GarveyWong
  8分钟前 看过

552127人看过 / 214122人想看

订阅可可西里的评论:
feed: rss 2.0